package network;

import structure.*;

/**
  A generic address.  Addresses identify clients of the network.
  Generic addresses may be compared for equality.  Real network
  implementations will likely have to extend this to model more
  interesting addressing schemes.   
  */
public class Address implements StructuredObject
{
  public Address ()
  {
    text = "";
  }
  
  /**
    Make a new address from a string.
    */
  public Address (String s)
  {
    text = s;
  }
  
  /**
    Convert the address to a string
    
    @return the string name the address was constructed with
    */
  public String toString ()
  {
    return text;
  }
  
  /**
    Compare two addresses
    
    @return <tt>true</tt> if the addresses represent the same
    client (in this case string equality).
    */
  public boolean equals (Address rhs)
  {
    return text.equals (rhs.text);
  }
  
  public void FoldOutStructure (StructuredStorage s)
  {
    s.SetString ("text", text);
  }
  
  public void FoldInStructure (StructuredStorage s)
  {
    text = s.GetString ("text");
  }
  
  private String text;
}





