package timer;

import java.io.*;
import java.util.*;
import debug.*;


/**
   A class to describe clients of the timer.  All
   classes wishing to use the features of the timer
   will need to <tt>extend</tt> this class, and most 
   will need to override the <tt>Timeout</tt> function 
   as well.  The purpose of this class is twofold:
   <ol>
   <li> To describe the callback interface for timeouts.  The method
        <tt>Timeout</tt> will be called (with the data object associated
	with the timeout) when timeouts fire.  Clients using timeouts will
	therefore need to override this function.
   <p>
</ol>
 *****************************************************************/

public class TimerClient
{
   /************************************************************
      the callback for timeouts.  When a timeout fires,
      this method on the client will be called.  The default
      implementation does nothing.

      @param info the object which was passed to <tt>SetTimeout</tt>
         when this timeout was set
      @see Timer#SetTimeout
    ************************************************************/
   public void Timeout (Object info)
   {
      // This space intentionally left bank
   }

   /************************************************************
      Block the currently executing thread indefiniately until
      <tt>Notify</tt> or <tt>NotifyAll</tt> is called.  The 
      current thread must hold the timer's monitor and be 
      registered as blocking simulated time.  While the thread
      is blocked both the monitor and simulated time will be 
      released.

      @throws IllegalMonitorStateException if the current
              thread does not hold the timer's monitor
      @throws IllegalTimerStateException if the current
              thread is not blocking simulated time.
    ************************************************************/
   public void Wait () throws IllegalMonitorStateException,
                              IllegalTimerStateException
   {
      try
         {
         Timer.global.wait ();
         }
      catch (InterruptedException e)
         {
         }
   }

   public void Wait (long us) throws IllegalMonitorStateException,
                                     IllegalTimerStateException
   {
      throw new IllegalTimerStateException ();
   }

   public void Notify () throws IllegalMonitorStateException,
                                IllegalTimerStateException
   {
      Timer.global.notifyAll ();
   }

   public void NotifyAll () throws IllegalMonitorStateException,
                                   IllegalTimerStateException
   {
      Timer.global.notifyAll ();
   }
}

